[evolution-data-server] Add CamelNetworkSettings.



commit 020f75a3d478249949f93e2087b0bc9cc31383e1
Author: Matthew Barnes <mbarnes redhat com>
Date:   Wed Aug 3 09:58:58 2011 -0500

    Add CamelNetworkSettings.
    
    Move the "security-method" property from CamelNetworkService to
    CamelNetworkSettings.  If a given CamelService subclass implements
    CamelNetworkService, its corresponding CamelSettings subclass should
    implement CamelNetworkSettings.

 camel/Makefile.am                                  |    2 +
 camel/camel-network-service.c                      |  141 ++++----------------
 camel/camel-network-service.h                      |   33 +++---
 camel/camel-network-settings.c                     |   95 +++++++++++++
 camel/camel-network-settings.h                     |   68 ++++++++++
 docs/reference/camel/camel-docs.sgml               |    1 +
 docs/reference/camel/camel-sections.txt            |   21 +++-
 docs/reference/camel/camel.types                   |    2 +
 .../camel/tmpl/camel-network-service.sgml          |   29 +----
 .../camel/tmpl/camel-network-settings.sgml         |   60 +++++++++
 docs/reference/camel/tmpl/camel-unused.sgml        |   16 +++
 11 files changed, 310 insertions(+), 158 deletions(-)
---
diff --git a/camel/Makefile.am b/camel/Makefile.am
index f27f128..63d12df 100644
--- a/camel/Makefile.am
+++ b/camel/Makefile.am
@@ -65,6 +65,7 @@ libcamel_provider_1_2_la_SOURCES = 		\
 	camel-gpg-context.c			\
 	camel-http-stream.c			\
 	camel-network-service.c			\
+	camel-network-settings.c		\
 	camel-offline-folder.c			\
 	camel-offline-journal.c			\
 	camel-offline-settings.c		\
@@ -117,6 +118,7 @@ libcamel_providerinclude_HEADERS =		\
 	camel-lock-helper.h			\
 	camel-movemail.h			\
 	camel-network-service.h			\
+	camel-network-settings.h		\
 	camel-offline-folder.h			\
 	camel-offline-journal.h			\
 	camel-offline-settings.h		\
diff --git a/camel/camel-network-service.h b/camel/camel-network-service.h
index 4eaa26f..dc8ec91 100644
--- a/camel/camel-network-service.h
+++ b/camel/camel-network-service.h
@@ -24,6 +24,7 @@
 #define CAMEL_NETWORK_SERVICE_H
 
 #include <camel/camel-enums.h>
+#include <camel/camel-network-settings.h>
 #include <camel/camel-stream.h>
 
 /* Standard GObject macros */
@@ -53,31 +54,31 @@ typedef struct _CamelNetworkServiceInterface CamelNetworkServiceInterface;
 struct _CamelNetworkServiceInterface {
 	GTypeInterface parent_interface;
 
-	const gchar *	(*get_service_name)	(CamelNetworkService *service);
-	guint16		(*get_default_port)	(CamelNetworkService *service);
+	const gchar *	(*get_service_name)
+					(CamelNetworkService *service,
+					 CamelNetworkSecurityMethod method);
+	guint16		(*get_default_port)
+					(CamelNetworkService *service,
+					 CamelNetworkSecurityMethod method);
 
-	CamelStream *	(*connect_sync)		(CamelNetworkService *service,
-						 GCancellable *cancellable,
-						 GError **error);
+	CamelStream *	(*connect_sync)	(CamelNetworkService *service,
+					 GCancellable *cancellable,
+					 GError **error);
 
 	gpointer reserved[16];
 };
 
 GType		camel_network_service_get_type	(void) G_GNUC_CONST;
 const gchar *	camel_network_service_get_service_name
-						(CamelNetworkService *service);
+					(CamelNetworkService *service,
+					 CamelNetworkSecurityMethod method);
 guint16		camel_network_service_get_default_port
-						(CamelNetworkService *service);
-CamelNetworkSecurityMethod
-		camel_network_service_get_security_method
-						(CamelNetworkService *service);
-void		camel_network_service_set_security_method
-						(CamelNetworkService *service,
-						 CamelNetworkSecurityMethod method);
+					(CamelNetworkService *service,
+					 CamelNetworkSecurityMethod method);
 CamelStream *	camel_network_service_connect_sync
-						(CamelNetworkService *service,
-						 GCancellable *cancellable,
-						 GError **error);
+					(CamelNetworkService *service,
+					 GCancellable *cancellable,
+					 GError **error);
 
 G_END_DECLS
 
diff --git a/camel/camel-network-settings.c b/camel/camel-network-settings.c
new file mode 100644
index 0000000..84caef0
--- /dev/null
+++ b/camel/camel-network-settings.c
@@ -0,0 +1,95 @@
+/*
+ * camel-network-settings.c
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ */
+
+#include "camel-network-settings.h"
+
+#include <camel/camel-enumtypes.h>
+#include <camel/camel-settings.h>
+
+#define SECURITY_METHOD_KEY "CamelNetworkSettings:security-method"
+
+G_DEFINE_INTERFACE (
+	CamelNetworkSettings,
+	camel_network_settings,
+	CAMEL_TYPE_SETTINGS)
+
+static void
+camel_network_settings_default_init (CamelNetworkSettingsInterface *interface)
+{
+	g_object_interface_install_property (
+		interface,
+		g_param_spec_enum (
+			"security-method",
+			"Security Method",
+			"Method used to establish a network connection",
+			CAMEL_TYPE_NETWORK_SECURITY_METHOD,
+			CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS));
+}
+
+/**
+ * camel_network_settings_get_security_method:
+ * @settings: a #CamelNetworkSettings
+ *
+ * Returns the method used to establish a secure (or unsecure) network
+ * connection.
+ *
+ * Returns: the security method
+ *
+ * Since: 3.2
+ **/
+CamelNetworkSecurityMethod
+camel_network_settings_get_security_method (CamelNetworkSettings *settings)
+{
+	gpointer data;
+
+	g_return_val_if_fail (
+		CAMEL_IS_NETWORK_SETTINGS (settings),
+		CAMEL_NETWORK_SECURITY_METHOD_NONE);
+
+	data = g_object_get_data (G_OBJECT (settings), SECURITY_METHOD_KEY);
+
+	return (CamelNetworkSecurityMethod) GPOINTER_TO_INT (data);
+}
+
+/**
+ * camel_network_settings_set_security_method:
+ * @settings: a #CamelNetworkSettings
+ * @method: the security method
+ *
+ * Sets the method used to establish a secure (or unsecure) network
+ * connection.  Note that changing this setting has no effect on an
+ * already-established network connection.
+ *
+ * Since: 3.2
+ **/
+void
+camel_network_settings_set_security_method (CamelNetworkSettings *settings,
+                                            CamelNetworkSecurityMethod method)
+{
+	g_return_if_fail (CAMEL_IS_NETWORK_SETTINGS (settings));
+
+	g_object_set_data (
+		G_OBJECT (settings),
+		SECURITY_METHOD_KEY,
+		GINT_TO_POINTER (method));
+
+	g_object_notify (G_OBJECT (settings), "security-method");
+}
diff --git a/camel/camel-network-settings.h b/camel/camel-network-settings.h
new file mode 100644
index 0000000..09aa360
--- /dev/null
+++ b/camel/camel-network-settings.h
@@ -0,0 +1,68 @@
+/*
+ * camel-network-settings.h
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ */
+
+#if !defined (__CAMEL_H_INSIDE__) && !defined (CAMEL_COMPILATION)
+#error "Only <camel/camel.h> can be included directly."
+#endif
+
+#ifndef CAMEL_NETWORK_SETTINGS_H
+#define CAMEL_NETWORK_SETTINGS_H
+
+#include <glib-object.h>
+#include <camel/camel-enums.h>
+
+/* Standard GObject macros */
+#define CAMEL_TYPE_NETWORK_SETTINGS \
+	(camel_network_settings_get_type ())
+#define CAMEL_NETWORK_SETTINGS(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), CAMEL_TYPE_NETWORK_SETTINGS, CamelNetworkSettings))
+#define CAMEL_NETWORK_SETTINGS_INTERFACE(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), CAMEL_TYPE_NETWORK_SETTINGS, CamelNetworkSettingsInterface))
+#define CAMEL_IS_NETWORK_SETTINGS(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), CAMEL_TYPE_NETWORK_SETTINGS))
+#define CAMEL_IS_NETWORK_SETTINGS_INTERFACE(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), CAMEL_TYPE_NETWORK_SETTINGS))
+#define CAMEL_NETWORK_SETTINGS_GET_INTERFACE(obj) \
+	(G_TYPE_INSTANCE_GET_INTERFACE \
+	((obj), CAMEL_TYPE_NETWORK_SETTINGS, CamelNetworkSettingsInterface))
+
+G_BEGIN_DECLS
+
+typedef struct _CamelNetworkSettings CamelNetworkSettings;
+typedef struct _CamelNetworkSettingsInterface CamelNetworkSettingsInterface;
+
+struct _CamelNetworkSettingsInterface {
+	GTypeInterface parent_interface;
+};
+
+GType		camel_network_settings_get_type
+					(void) G_GNUC_CONST;
+CamelNetworkSecurityMethod
+		camel_network_settings_get_security_method
+					(CamelNetworkSettings *settings);
+void		camel_network_settings_set_security_method
+					(CamelNetworkSettings *settings,
+					 CamelNetworkSecurityMethod method);
+
+G_END_DECLS
+
+#endif /* CAMEL_NETWORK_SETTINGS_H */
diff --git a/docs/reference/camel/camel-docs.sgml b/docs/reference/camel/camel-docs.sgml
index 3771324..a1097aa 100644
--- a/docs/reference/camel/camel-docs.sgml
+++ b/docs/reference/camel/camel-docs.sgml
@@ -96,6 +96,7 @@
       <xi:include href="xml/camel-offline-store.xml"/>
       <xi:include href="xml/camel-transport.xml"/>
       <xi:include href="xml/camel-settings.xml"/>
+      <xi:include href="xml/camel-network-settings.xml"/>
       <xi:include href="xml/camel-store-settings.xml"/>
       <xi:include href="xml/camel-offline-settings.xml"/>
     </chapter>
diff --git a/docs/reference/camel/camel-sections.txt b/docs/reference/camel/camel-sections.txt
index 5cc3642..bf57731 100644
--- a/docs/reference/camel/camel-sections.txt
+++ b/docs/reference/camel/camel-sections.txt
@@ -1480,9 +1480,6 @@ camel_multipart_get_type
 CamelNetworkService
 camel_network_service_get_default_port
 camel_network_service_get_service_name
-CamelNetworkSecurityMethod
-camel_network_service_get_security_method
-camel_network_service_set_security_method
 camel_network_service_connect_sync
 <SUBSECTION Standard>
 CAMEL_NETWORK_SERVICE
@@ -1496,6 +1493,24 @@ camel_network_service_get_type
 </SECTION>
 
 <SECTION>
+<FILE>camel-network-settings</FILE>
+<TITLE>CamelNetworkSettings</TITLE>
+CamelNetworkSettings
+CamelNetworkSecurityMethod
+camel_network_settings_get_security_method
+camel_network_settings_set_security_method
+<SUBSECTION Standard>
+CAMEL_NETWORK_SETTINGS
+CAMEL_IS_NETWORK_SETTINGS
+CAMEL_TYPE_NETWORK_SETTINGS
+CAMEL_NETWORK_SETTINGS_INTERFACE
+CAMEL_IS_NETWORK_SETTINGS_INTERFACE
+CAMEL_NETWORK_SETTINGS_GET_INTERFACE
+CamelNetworkSettingsInterface
+camel_network_settings_get_type
+</SECTION>
+
+<SECTION>
 <FILE>camel-nntp-address</FILE>
 <TITLE>CamelNNTPAddress</TITLE>
 CamelNNTPAddress
diff --git a/docs/reference/camel/camel.types b/docs/reference/camel/camel.types
index 5af9182..35e8b5e 100644
--- a/docs/reference/camel/camel.types
+++ b/docs/reference/camel/camel.types
@@ -47,6 +47,8 @@ camel_mime_part_get_type
 camel_multipart_encrypted_get_type
 camel_multipart_get_type
 camel_multipart_signed_get_type
+camel_network_service_get_type
+camel_network_settings_get_type
 camel_nntp_address_get_type
 camel_object_get_type
 camel_offline_folder_get_type
diff --git a/docs/reference/camel/tmpl/camel-network-service.sgml b/docs/reference/camel/tmpl/camel-network-service.sgml
index 7c2fadd..fa97232 100644
--- a/docs/reference/camel/tmpl/camel-network-service.sgml
+++ b/docs/reference/camel/tmpl/camel-network-service.sgml
@@ -32,6 +32,7 @@ CamelNetworkService
 </para>
 
 @service: 
+ method: 
 @Returns: 
 
 
@@ -41,34 +42,8 @@ CamelNetworkService
 </para>
 
 @service: 
- Returns: 
-
-
-<!-- ##### ENUM CamelNetworkSecurityMethod ##### -->
-<para>
-
-</para>
-
- CAMEL_NETWORK_SECURITY_METHOD_NONE: 
- CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT: 
- CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT: 
-
-<!-- ##### FUNCTION camel_network_service_get_security_method ##### -->
-<para>
-
-</para>
-
- service: 
- Returns: 
-
-
-<!-- ##### FUNCTION camel_network_service_set_security_method ##### -->
-<para>
-
-</para>
-
- service: 
 @method: 
+ Returns: 
 
 
 <!-- ##### FUNCTION camel_network_service_connect_sync ##### -->
diff --git a/docs/reference/camel/tmpl/camel-network-settings.sgml b/docs/reference/camel/tmpl/camel-network-settings.sgml
new file mode 100644
index 0000000..e49f882
--- /dev/null
+++ b/docs/reference/camel/tmpl/camel-network-settings.sgml
@@ -0,0 +1,60 @@
+<!-- ##### SECTION Title ##### -->
+CamelNetworkSettings
+
+<!-- ##### SECTION Short_Description ##### -->
+
+
+<!-- ##### SECTION Long_Description ##### -->
+<para>
+
+</para>
+
+<!-- ##### SECTION See_Also ##### -->
+<para>
+
+</para>
+
+<!-- ##### SECTION Stability_Level ##### -->
+
+
+<!-- ##### SECTION Image ##### -->
+
+
+<!-- ##### STRUCT CamelNetworkSettings ##### -->
+<para>
+
+</para>
+
+
+<!-- ##### ARG CamelNetworkSettings:security-method ##### -->
+<para>
+
+</para>
+
+<!-- ##### ENUM CamelNetworkSecurityMethod ##### -->
+<para>
+
+</para>
+
+ CAMEL_NETWORK_SECURITY_METHOD_NONE: 
+ CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT: 
+ CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT: 
+
+<!-- ##### FUNCTION camel_network_settings_get_security_method ##### -->
+<para>
+
+</para>
+
+ settings: 
+ Returns: 
+
+
+<!-- ##### FUNCTION camel_network_settings_set_security_method ##### -->
+<para>
+
+</para>
+
+ settings: 
+ method: 
+
+
diff --git a/docs/reference/camel/tmpl/camel-unused.sgml b/docs/reference/camel/tmpl/camel-unused.sgml
index 069eeb1..32b42ea 100644
--- a/docs/reference/camel/tmpl/camel-unused.sgml
+++ b/docs/reference/camel/tmpl/camel-unused.sgml
@@ -7500,6 +7500,22 @@ streams
 @name: 
 @Returns: 
 
+<!-- ##### FUNCTION camel_network_service_get_security_method ##### -->
+<para>
+
+</para>
+
+ service: 
+ Returns: 
+
+<!-- ##### FUNCTION camel_network_service_set_security_method ##### -->
+<para>
+
+</para>
+
+ service: 
+ method: 
+
 <!-- ##### FUNCTION camel_news_address_new ##### -->
 <para>
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/camel/camel-network-service.c b/camel/camel-network-service.c
index ee7d1b6..7914e7d 100644
--- a/camel/camel-network-service.c
+++ b/camel/camel-network-service.c
@@ -22,6 +22,7 @@
 #include <glib/gi18n-lib.h>
 
 #include <camel/camel-enumtypes.h>
+#include <camel/camel-network-settings.h>
 #include <camel/camel-service.h>
 #include <camel/camel-session.h>
 #include <camel/camel-tcp-stream-raw.h>
@@ -41,6 +42,7 @@ network_service_connect_sync (CamelNetworkService *service,
                               GError **error)
 {
 	CamelNetworkSecurityMethod method;
+	CamelSettings *settings;
 	CamelSession *session;
 	CamelStream *stream;
 	CamelURL *url;
@@ -52,10 +54,15 @@ network_service_connect_sync (CamelNetworkService *service,
 
 	url = camel_service_get_camel_url (CAMEL_SERVICE (service));
 	session = camel_service_get_session (CAMEL_SERVICE (service));
+	settings = camel_service_get_settings (CAMEL_SERVICE (service));
 
-	method = camel_network_service_get_security_method (service);
-	service_name = camel_network_service_get_service_name (service);
-	default_port = camel_network_service_get_default_port (service);
+	if (CAMEL_IS_NETWORK_SETTINGS (settings))
+		g_object_get (settings, "security-method", &method, NULL);
+	else
+		method = CAMEL_NETWORK_SECURITY_METHOD_NONE;
+
+	service_name = camel_network_service_get_service_name (service, method);
+	default_port = camel_network_service_get_default_port (service, method);
 
 	/* If the URL explicitly gives a port number, make
 	 * it override the service name and default port. */
@@ -125,58 +132,25 @@ static void
 camel_network_service_default_init (CamelNetworkServiceInterface *interface)
 {
 	interface->connect_sync = network_service_connect_sync;
-
-	g_object_interface_install_property (
-		interface,
-		g_param_spec_uint (
-			"default-port",
-			"Default Port",
-			"Default IP port",
-			0,
-			G_MAXUINT16,
-			0,
-			G_PARAM_READABLE |
-			G_PARAM_STATIC_STRINGS));
-
-	g_object_interface_install_property (
-		interface,
-		g_param_spec_enum (
-			"security-method",
-			"Security Method",
-			"Method used to establish a network connection",
-			CAMEL_TYPE_NETWORK_SECURITY_METHOD,
-			CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT |
-			G_PARAM_STATIC_STRINGS));
-
-	g_object_interface_install_property (
-		interface,
-		g_param_spec_string (
-			"service-name",
-			"Service Name",
-			"Network service name",
-			NULL,
-			G_PARAM_READABLE |
-			G_PARAM_STATIC_STRINGS));
 }
 
 /**
  * camel_network_service_get_service_name:
  * @service: a #CamelNetworkService
+ * @method: a #CamelNetworkSecurityMethod
  *
- * Returns the standard network service name for @service as defined
- * in /etc/services.  The service name may depend on the value of the
- * #CamelNetworkService:security-method property.  For example, the
- * service name for unencrypted IMAP or encrypted IMAP using STARTTLS
- * is "imap", but the service name for IMAP over SSL is "imaps".
+ * Returns the standard network service name for @service and the security
+ * method @method, as defined in /etc/services.  For example, the service
+ * name for unencrypted IMAP or encrypted IMAP using STARTTLS is "imap",
+ * but the service name for IMAP over SSL is "imaps".
  *
- * Returns: the network service name for @service, or %NULL
+ * Returns: the network service name for @service and @method, or %NULL
  *
  * Since: 3.2
  **/
 const gchar *
-camel_network_service_get_service_name (CamelNetworkService *service)
+camel_network_service_get_service_name (CamelNetworkService *service,
+                                        CamelNetworkSecurityMethod method)
 {
 	CamelNetworkServiceInterface *interface;
 	const gchar *service_name = NULL;
@@ -186,7 +160,7 @@ camel_network_service_get_service_name (CamelNetworkService *service)
 	interface = CAMEL_NETWORK_SERVICE_GET_INTERFACE (service);
 
 	if (interface->get_service_name != NULL)
-		service_name = interface->get_service_name (service);
+		service_name = interface->get_service_name (service, method);
 
 	return service_name;
 }
@@ -194,19 +168,20 @@ camel_network_service_get_service_name (CamelNetworkService *service)
 /**
  * camel_network_service_get_default_port:
  * @service: a #CamelNetworkService
+ * @method: a #CamelNetworkSecurityMethod
  *
- * Returns the default network port number of @service as defined
- * in /etc/services.  The default port may depend on the value of the
- * #CamelNetworkService:security-method property.  For example, the
- * default port for unencrypted IMAP or encrypted IMAP using STARTTLS
- * is 143, but the default port for IMAP over SSL is 993.
+ * Returns the default network port number for @service and the security
+ * method @method, as defined in /etc/services.  For example, the default
+ * port for unencrypted IMAP or encrypted IMAP using STARTTLS is 143, but
+ * the default port for IMAP over SSL is 993.
  *
- * Returns: the default port number for @service
+ * Returns: the default port number for @service and @method
  *
  * Since: 3.2
  **/
 guint16
-camel_network_service_get_default_port (CamelNetworkService *service)
+camel_network_service_get_default_port (CamelNetworkService *service,
+                                        CamelNetworkSecurityMethod method)
 {
 	CamelNetworkServiceInterface *interface;
 	guint16 default_port = 0;
@@ -216,77 +191,19 @@ camel_network_service_get_default_port (CamelNetworkService *service)
 	interface = CAMEL_NETWORK_SERVICE_GET_INTERFACE (service);
 
 	if (interface->get_default_port != NULL)
-		default_port = interface->get_default_port (service);
+		default_port = interface->get_default_port (service, method);
 
 	return default_port;
 }
 
 /**
- * camel_network_service_get_security_method:
- * @service: a #CamelNetworkService
- *
- * Return the method used to establish a secure (or unsecure) network
- * connection.
- *
- * Returns: the security method
- *
- * Since: 3.2
- **/
-CamelNetworkSecurityMethod
-camel_network_service_get_security_method (CamelNetworkService *service)
-{
-	gpointer data;
-
-	g_return_val_if_fail (
-		CAMEL_IS_NETWORK_SERVICE (service),
-		CAMEL_NETWORK_SECURITY_METHOD_NONE);
-
-	data = g_object_get_data (
-		G_OBJECT (service), "CamelNetworkService:security-method");
-
-	return (CamelNetworkSecurityMethod) GPOINTER_TO_INT (data);
-}
-
-/**
- * camel_network_service_set_security_method:
- * @service: a #CamelNetworkService
- * @method: the security method
- *
- * Sets the method used to establish a secure (or unsecure) network
- * connection.  Note that changing this setting has no effect on an
- * already-established network connection.
- *
- * Since: 3.2
- **/
-void
-camel_network_service_set_security_method (CamelNetworkService *service,
-                                           CamelNetworkSecurityMethod method)
-{
-	GObject *object;
-
-	g_return_if_fail (CAMEL_IS_NETWORK_SERVICE (service));
-
-	object = G_OBJECT (service);
-
-	g_object_set_data (
-		object, "CamelNetworkService:security-method",
-		GINT_TO_POINTER (method));
-
-	g_object_freeze_notify (object);
-	g_object_notify (object, "default-port");
-	g_object_notify (object, "security-method");
-	g_object_notify (object, "service-name");
-	g_object_thaw_notify (object);
-}
-
-/**
  * camel_network_service_connect_sync:
  * @service: a #CamelNetworkService
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Attempts to establish a network connection to the server described by
  * @service, using the preferred #CamelNetworkService:security-method to
  * secure the connection.  If a connection cannot be established, or the
  * connection attempt is cancelled, the function sets @error and returns
  * %NULL.
@@ -216,77 +191,19 @@ camel_network_service_get_default_port (CamelNetworkService *service)
  *
  * Attempts to establish a network connection to the server described by
- * @service, using the preferred #CamelNetworkService:security-method to
+ * @service, using the preferred #CamelNetworkSettings:security-method to
  * secure the connection.  If a connection cannot be established, or the
  * connection attempt is cancelled, the function sets @error and returns